@@ -1,8 +1,8 @@
 #
 # Configuration file for using the XML library in GNOME applications
 #
-XML2_LIBDIR="-L${libdir}"
+XML2_LIBDIR="-L/usr/lib"
 XML2_LIBS="-lxml2 -lz -lpthread  -lm "
-XML2_INCLUDEDIR="-I${includedir}/libxml2"
-MODULE_VERSION="xml2-2.5.11"
+XML2_INCLUDEDIR="-I/usr/include/libxml2"
+MODULE_VERSION="xml2-2.6.9"
 
